@@ -1,8 +1,9 @@
-plot.cums <-  function (object, pointwise.ci=1, hw.ci=0,
+plot.cums <-  function (x , pointwise.ci=1, hw.ci=0,
 sim.ci=0, robust=0, specific.comps=FALSE,level=0.05, start.time = 0, 
 stop.time = 0, add.to.plot=FALSE, mains=TRUE, xlab="Time",
 ylab ="Cumulative coefficients",...) 
 {
+ object<-x; rm(x); 
  B<-object$cum; V<-object$var.cum; p<-dim(B)[[2]]; 
  if (robust>=1) {V<-object$robvar.cum;}
 
